const project_name = "corvus";

// In this file change only project_name
const project = {
  text_domain: "" || project_name,
  packageName: "" || project_name,
  url: "http://localhost/" + project_name,

  uploads_dir: {
    files: "../../uploads/**",
    filesDest: "../../uploads/**",
  },

  scss: {
    custom: {
      src: "assets/scss/main.scss",
      dest: "assets/css/",
      watch: "assets/scss/**/*.scss",
    },
    reset: {
      src: "assets/reset-scss/reset.scss",
      dest: "assets/css/",
      watch: "assets/reset-scss/**/*.scss",
    },
  },
  js: {
    custom: {
      fileName: "main",
      src: "assets/js/concat/*.js",
      dest: "assets/js/",
      watch: ["assets/js/concat/*.js"],
    },
    vendor: {
      folderName: "vendor",
      src: "assets/vendor/js/*.js",
      dest: "assets/js/",
      watch: ["assets/vendor/js/*.js"],
    },
  },
  icon_font: {
    font_name: "icon-font",
    src: "assets/icons/*.svg",
    dest: "assets/fonts/icons/",
    class: "icon",
    font_path: "../fonts/icons/",
    path: "assets/scss/utilities/_icons-config.scss",
    targetPath: "../../scss/general/_icons.scss",
    formats: ["woff2", "woff", "ttf"],
  },
  php: {
    watch: "**/*.php",
  },
  settings: {
    browsers_autoprefixes: [
      "last 3 version",
      "> 1%",
      "ie >= 9",
      "ie_mob >= 10",
      "ff >= 30",
      "chrome >= 34",
      "safari >= 7",
      "opera >= 23",
      "ios >= 7",
      "android >= 4",
      "bb >= 10",
    ],
  },
};

const { parallel, series, dest, watch, src } = require("gulp");
const imagemin = require("gulp-imagemin");
const pngcrush = require("imagemin-pngcrush");
const sass = require("gulp-sass");
const minifycss = require("gulp-uglifycss");
const autoprefixer = require("gulp-autoprefixer");
const mmq = require("gulp-merge-media-queries");
const concat = require("gulp-concat");
const uglify = require("gulp-uglify");
const rename = require("gulp-rename");
const lineec = require("gulp-line-ending-corrector");
const filter = require("gulp-filter");
const sourcemaps = require("gulp-sourcemaps");
const notify = require("gulp-notify");
const browserSync = require("browser-sync").create();
const wpPot = require("gulp-wp-pot");
const sort = require("gulp-sort");
const iconfont = require("gulp-iconfont");
const iconfontCss = require("gulp-iconfont-css");
const babel = require("gulp-babel");

// Generate font from svg
function fontIcons() {
  return src([project.icon_font.src])
    .pipe(
      iconfontCss({
        fontName: project.icon_font.font_name,
        cssClass: project.icon_font.class,
        path: project.icon_font.path,
        targetPath: project.icon_font.targetPath,
        fontPath: project.icon_font.font_path,
      })
    )
    .pipe(
      iconfont({
        fontName: project.icon_font.font_name,
        prependUnicode: true,
        formats: project.icon_font.formats,
        normalize: true,
        centerHorizontally: true,
      })
    )
    .pipe(dest(project.icon_font.dest));
}

// Browser sync and local server
function browser_sync() {
  return browserSync.init({
    proxy: project.url,
    open: true,
    injectChanges: true,
  });
}

// Compailing SCSS
function styles() {
  let task_name = this.process.title;

  if (task_name == "gulp build") {
    return src(project.scss.custom.src)
      .pipe(
        sass({
          errLogToConsole: true,
          outputStyle: "compressed",
          precision: 10,
        })
      )
      .on("error", console.error.bind(console))
      .pipe(autoprefixer(project.settings.browsers_autoprefixes))

      .pipe(dest(project.scss.custom.dest))

      .pipe(filter("**/*.css"))
      .pipe(mmq({ log: true }))

      .pipe(rename({ suffix: ".min" }))
      .pipe(minifycss())
      .pipe(lineec())
      .pipe(dest(project.scss.custom.dest))

      .pipe(filter("**/*.css"))

      .pipe(notify({ message: 'TASK: "styles" Completed!', onLast: true }));
  } else {
    return src(project.scss.custom.src)
      .pipe(sourcemaps.init({ loadMaps: true }))
      .pipe(
        sass({
          errLogToConsole: true,
          outputStyle: "compact",
          precision: 10,
        })
      )
      .on("error", console.error.bind(console))
      .pipe(autoprefixer(project.settings.browsers_autoprefixes))

      .pipe(lineec())
      .pipe(filter("**/*.css"))

      .pipe(rename({ suffix: ".min" }))

      .pipe(lineec())
      .pipe(sourcemaps.write())

      .pipe(dest(project.scss.custom.dest))

      .pipe(filter("**/*.css"))
      .pipe(browserSync.stream())

      .pipe(notify({ message: 'TASK: "styles" Completed!', onLast: true }));
  }
}

// Compailing reset SCSS
function resetStyles() {
  return src(project.scss.reset.src)
    .pipe(
      sass({
        errLogToConsole: true,
        outputStyle: "compressed",
        precision: 10,
      })
    )
    .on("error", console.error.bind(console))
    .pipe(autoprefixer(project.settings.browsers_autoprefixes))

    .pipe(dest(project.scss.reset.dest))

    .pipe(filter("**/*.css"))
    .pipe(mmq({ log: true }))

    .pipe(rename({ suffix: ".min" }))
    .pipe(minifycss())
    .pipe(lineec())
    .pipe(dest(project.scss.reset.dest))

    .pipe(filter("**/.css"))
    .pipe(notify({ message: 'TASK: "reset styles" Completed!', onLast: true }));
}

// Compiling vendor JS
function vendorJS() {
  return src(project.js.vendor.src)
    .pipe(concat(project.js.vendor.folderName + ".js"))
    .pipe(lineec()) // Consistent Line Endings for non UNIX systems.
    .pipe(dest(project.js.vendor.dest))
    .pipe(
      rename({
        basename: project.js.vendor.folderName,
        suffix: ".min",
      })
    )
    .pipe(uglify())
    .pipe(lineec()) // Consistent Line Endings for non UNIX systems.
    .pipe(dest(project.js.vendor.dest))
    .pipe(browserSync.stream())
    .pipe(notify({ message: 'TASK: "vendorsJs" Completed!', onLast: true }));
}

// Compiling custom JS
function customJS() {
  return src(project.js.custom.src)
    .pipe(babel())
    .pipe(concat(project.js.custom.fileName + ".js"))
    .pipe(lineec()) // Consistent Line Endings for non UNIX systems.
    .pipe(dest(project.js.custom.dest))
    .pipe(
      rename({
        basename: project.js.custom.fileName,
        suffix: ".min",
      })
    )
    .pipe(uglify())
    .pipe(lineec()) // Consistent Line Endings for non UNIX systems.
    .pipe(dest(project.js.custom.dest))
    .pipe(browserSync.stream())
    .pipe(notify({ message: 'TASK: "customJs" Completed!', onLast: true }));
}

// Generate pot file from theme
function translate() {
  return src(project.php.watch)
    .pipe(sort())
    .pipe(
      wpPot({
        domain: project.text_domain,
        package: project.packageName,
      })
    )
    .pipe(dest("languages/"))
    .pipe(notify({ message: 'TASK: "translate" Completed!', onLast: true }));
}

// Optimization image
function imageOptimization() {
  "use strict";

  return src(project.uploads_dir.files, { base: project.uploads_dir.files })
    .pipe(
      imagemin({
        interlaced: true,
        progressive: true,
        optimizationLevel: 7,
        svgoPlugins: [{ removeViewBox: false }],
        use: [pngcrush()],
      })
    )
    .pipe(dest(project.uploads_dir.filesDest));
}

// Watch JS and SCSS
function watchFiles() {
  watch(project.scss.custom.watch, styles);
  watch(project.js.vendor.watch, vendorJS);
  watch(project.js.custom.watch, customJS);
}

// Tasks
exports.styles = styles; // gulp styles - build css
exports.resetStyles = resetStyles; // gulp reset styles - build reset css
exports.vendorJS = vendorJS; // gulp vendorJS - build vendor JS
exports.customJS = customJS; // gulp customJS - build custom JS
exports.translate = translate; // gulp translate - generate theme POT file
exports.images = imageOptimization; // gulp images - optimization uploaded assets

exports.fontIcons = fontIcons; // gulp fontIcons - make icons from svg

// Main tasks
exports.default = series(parallel(browser_sync, watchFiles)); // gulp - default task with browser sync
exports.watch = watchFiles; // gulp watch - watch files without browser sync
exports.build = series(parallel(styles, vendorJS, customJS, translate)); // gulp build - build site minify css and js
