<?php

/**
 * Corvus functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Corvus
 */

if (!function_exists('kamaengine_setup')) :
   /**
    * Sets up theme defaults and registers support for various WordPress features.
    *
    * Note that this function is hooked into the after_setup_theme hook, which
    * runs before the init hook. The init hook is too late for some features, such
    * as indicating support for post thumbnails.
    */
   function kamaengine_setup()
   {
      /*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme kamaengined on Corvus, use a find and replace
		 * to change 'corvus' to the name of your theme in all the template files.
		 */
      load_theme_textdomain('corvus', get_template_directory() . '/languages');

      // Add default posts and comments RSS feed links to head.
      add_theme_support('automatic-feed-links');

      /*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
      add_theme_support('title-tag');

      /*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
      add_theme_support('post-thumbnails');

      /*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
      add_theme_support('html5', array(
         'search-form',
         'comment-form',
         'comment-list',
         'gallery',
         'caption',
      ));

      // Add theme support for selective refresh for widgets.
      add_theme_support('customize-selective-refresh-widgets');

      /**
       * Add support for core custom logo.
       *
       * @link https://codex.wordpress.org/Theme_Logo
       */
      add_theme_support('custom-logo', array(
         'height'      => 250,
         'width'       => 250,
         'flex-width'  => true,
         'flex-height' => true,
      ));
   }
endif;
add_action('after_setup_theme', 'kamaengine_setup');

/**
 * Set the content width in pixels, kamaengined on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function kamaengine_content_width()
{
   // This variable is intended to be overruled from themes.
   // Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
   // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
   $GLOBALS['content_width'] = apply_filters('kamaengine_content_width', 640);
}
add_action('after_setup_theme', 'kamaengine_content_width', 0);

/**
 * Enqueue scripts and styles.
 */
function kamaengine_scripts()
{
   wp_enqueue_style('corvus-style', get_stylesheet_uri());
   wp_enqueue_style('main-css', get_stylesheet_directory_uri() . '/assets/css/main.min.css');

   wp_enqueue_script('vendor-main', get_template_directory_uri() . '/assets/js/vendor.min.js', array('jquery'), '1.0', true);
   wp_enqueue_script('main', get_template_directory_uri() . '/assets/js/main.min.js', array('jquery'), '1.1', true);

   wp_dequeue_style('wp-block-library');

   if (is_singular() && comments_open() && get_option('thread_comments')) {
      wp_enqueue_script('comment-reply');
   }

   /**************************************************
    * Passed data in JS
    **************************************************/
   $dataToBePassed = array(
      'themeUrl'   => get_stylesheet_directory_uri(),
      'ajaxUrl'   => admin_url('admin-ajax.php')
   );

   wp_localize_script('main', 'GlobalThemeData', $dataToBePassed);
}

add_action('wp_enqueue_scripts', 'kamaengine_scripts');

// Dashboard custom style css
function admin_style()
{
   wp_register_style('admin_css', get_stylesheet_directory_uri() . '/assets/css/admin.css', false, '1.0.0');
   wp_enqueue_style('admin_css', get_stylesheet_directory_uri() . '/assets/css/admin.css', false, '1.0.0');
}
add_action('admin_enqueue_scripts', 'admin_style');

// Theme global settings
global $theme_settings;
$theme_settings = [
   'theme-color' => "#fff",
   'footer-areas' => 3,
   'show-copyright' => false
];

/**************************************************
 * Include Theme functions
 **************************************************/
require get_template_directory() . '/inc/theme-include.php';
/**************************************************
 * Init all development files 
 **************************************************/
require get_template_directory() . '/inc/development/index.php';
/**************************************************
 * Init  Custom Post Type
 **************************************************/
require get_template_directory() . '/inc/cpt/index.php';
